@@ -6,7 +6,12 @@ from .api import (
     Hint,
     HintOrType,
     HintType,
+    InstOrType,
     KeywordArgumentError,
+    Lookup,
+    LookupOrType,
+    LookupType,
+    OptionalKwargs,
     Resolver,
     UnexpectedKeywordError,
     get_cls,
@@ -16,9 +21,14 @@ from .api import (
 
 __all__ = [
     # Type Hints
+    "InstOrType",
+    "Lookup",
+    "LookupType",
+    "LookupOrType",
     "Hint",
     "HintType",
     "HintOrType",
+    "OptionalKwargs",
     # Classes
     "Resolver",
     # Utilities
