@@ -7,6 +7,7 @@ import logging
 from operator import attrgetter
 from textwrap import dedent
 from typing import (
+    TYPE_CHECKING,
     Any,
     Callable,
     Collection,
@@ -17,7 +18,6 @@ from typing import (
     Mapping,
     Optional,
     Set,
-    TYPE_CHECKING,
     Type,
     TypeVar,
     Union,
@@ -37,6 +37,7 @@ __all__ = [
     "Hint",
     "HintType",
     "HintOrType",
+    "OptionalKwargs",
     # Classes
     "Resolver",
     # Utilities
@@ -61,6 +62,8 @@ Hint = Optional[Lookup[X]]
 HintType = Hint[Type[X]]
 HintOrType = Hint[InstOrType[X]]
 
+OptionalKwargs = Optional[Mapping[str, Any]]
+
 logger = logging.getLogger(__name__)
 
 
