@@ -8,7 +8,7 @@ import unittest
 import click
 from click.testing import CliRunner, Result
 
-from class_resolver import Resolver
+from class_resolver import Resolver, UnexpectedKeywordError
 
 try:
     import ray.tune as tune
@@ -40,6 +40,14 @@ class C(Base):
     """C base class."""
 
 
+class AltBase:
+    """An alternative base class."""
+
+
+class AAltBase(AltBase):
+    """A base class."""
+
+
 class TestResolver(unittest.TestCase):
     """Tests for the resolver."""
 
@@ -49,8 +57,8 @@ class TestResolver(unittest.TestCase):
 
     def test_lookup(self):
         """Test looking up classes."""
-        self.assertEqual(A, self.resolver.lookup('a'))
-        self.assertEqual(A, self.resolver.lookup('A'))
+        self.assertEqual(A, self.resolver.lookup("a"))
+        self.assertEqual(A, self.resolver.lookup("A"))
 
     def test_iterator(self):
         """Test iterating over classes."""
@@ -58,32 +66,35 @@ class TestResolver(unittest.TestCase):
 
     def test_make(self):
         """Test making classes."""
-        name = 'charlie'
+        name = "charlie"
         # Test instantiating with positional dict into kwargs
-        self.assertEqual(A(name=name), self.resolver.make('a', {'name': name}))
+        self.assertEqual(A(name=name), self.resolver.make("a", {"name": name}))
         # Test instantiating with kwargs
-        self.assertEqual(A(name=name), self.resolver.make('a', name=name))
+        self.assertEqual(A(name=name), self.resolver.make("a", name=name))
 
     def test_make_from_kwargs(self):
         """Test making classes from kwargs."""
         name = "charlie"
-        self.assertEqual(A(name=name), self.resolver.make_from_kwargs(
-            key="magic",
-            data=dict(
-                ignored_entry=...,
-                magic="a",
-                magic_kwargs=dict(
-                    name=name,
+        self.assertEqual(
+            A(name=name),
+            self.resolver.make_from_kwargs(
+                key="magic",
+                data=dict(
+                    ignored_entry=...,
+                    magic="a",
+                    magic_kwargs=dict(
+                        name=name,
+                    ),
                 ),
             ),
-        ))
+        )
 
     def test_passthrough(self):
         """Test instances are passed through unmodified."""
-        a = A(name='charlie')
+        a = A(name="charlie")
         self.assertEqual(a, self.resolver.make(a))
 
-    @unittest.skipIf(tune is None, 'ray[tune] was not installed properly')
+    @unittest.skipIf(tune is None, "ray[tune] was not installed properly")
     def test_variant_generation(self):
         """Test whether ray tune can generate variants from the search space."""
         search_space = self.resolver.ray_tune_search_space(
@@ -91,11 +102,10 @@ class TestResolver(unittest.TestCase):
                 name=tune.choice(["charlie", "max"]),
             ),
         )
-        for spec in itertools.islice(tune.suggest.variant_generator.generate_variants(search_space), 2):
-            config = {
-                k[0]: v
-                for k, v in spec[0].items()
-            }
+        for spec in itertools.islice(
+            tune.suggest.variant_generator.generate_variants(search_space), 2
+        ):
+            config = {k[0]: v for k, v in spec[0].items()}
             query = config.pop("query")
             instance = self.resolver.make(query=query, pos_kwargs=config)
             self.assertIsInstance(instance, Base)
@@ -103,13 +113,13 @@ class TestResolver(unittest.TestCase):
     def test_bad_click_option(self):
         """Test failure to get a click option."""
         with self.assertRaises(ValueError):
-            self.resolver.get_option('--opt')  # no default given
+            self.resolver.get_option("--opt")  # no default given
 
     def test_click_option(self):
         """Test the click option."""
 
         @click.command()
-        @self.resolver.get_option('--opt', default='a')
+        @self.resolver.get_option("--opt", default="a")
         def cli(opt):
             """Run the test CLI."""
             self.assertIsInstance(opt, type)
@@ -125,18 +135,18 @@ class TestResolver(unittest.TestCase):
         self.assertEqual(A.__name__, result.output)
 
         # Test canonical name
-        result: Result = runner.invoke(cli, ['--opt', 'A'])
+        result: Result = runner.invoke(cli, ["--opt", "A"])
         self.assertEqual(A.__name__, result.output)
 
         # Test normalizing name
-        result: Result = runner.invoke(cli, ['--opt', 'a'])
+        result: Result = runner.invoke(cli, ["--opt", "a"])
         self.assertEqual(A.__name__, result.output)
 
     def test_click_option_str(self):
         """Test the click option."""
 
         @click.command()
-        @self.resolver.get_option('--opt', default='a', as_string=True)
+        @self.resolver.get_option("--opt", default="a", as_string=True)
         def cli(opt):
             """Run the test CLI."""
             self.assertIsInstance(opt, str)
@@ -146,5 +156,12 @@ class TestResolver(unittest.TestCase):
 
     def test_signature(self):
         """Check signature tests."""
-        self.assertTrue(self.resolver.supports_argument('A', 'name'))
-        self.assertFalse(self.resolver.supports_argument('A', 'nope'))
+        self.assertTrue(self.resolver.supports_argument("A", "name"))
+        self.assertFalse(self.resolver.supports_argument("A", "nope"))
+
+    def test_no_arguments(self):
+        """Check that the unexpected keyword error is thrown properly."""
+        resolver = Resolver.from_subclasses(AltBase)
+        with self.assertRaises(UnexpectedKeywordError) as e:
+            resolver.make("A", nope="nopppeeee")
+            self.assertEqual("AAltBase did not expect any keyword arguments", str(e))
